@@ -182,6 +182,8 @@ def open_coordinate_conversion_dataset(
     coordinate_conversion = esa_safe.parse_tag_as_list(
         annotation_path, ".//coordinateConversionList/coordinateConversion"
     )
+    if len(coordinate_conversion) == 0:
+        raise TypeError("coordinateConversion tag not present in annotations")
 
     gr0 = []
     sr0 = []
@@ -203,15 +205,14 @@ def open_coordinate_conversion_dataset(
 
     coords: Dict[str, Any] = {}
     data_vars: Dict[str, Any] = {}
-    if srgrCoefficients:
-        coords["azimuth_time"] = [np.datetime64(dt) for dt in azimuth_time]
-        coords["degree"] = list(range(len(srgrCoefficients[0])))
+    coords["azimuth_time"] = [np.datetime64(dt) for dt in azimuth_time]
+    coords["degree"] = list(range(len(srgrCoefficients[0])))
 
-        data_vars["gr0"] = ("azimuth_time", gr0)
-        data_vars["sr0"] = ("azimuth_time", sr0)
-        data_vars["slant_range_time"] = ("azimuth_time", slant_range_time)
-        data_vars["srgrCoefficients"] = (("azimuth_time", "degree"), srgrCoefficients)
-        data_vars["grsrCoefficients"] = (("azimuth_time", "degree"), grsrCoefficients)
+    data_vars["gr0"] = ("azimuth_time", gr0)
+    data_vars["sr0"] = ("azimuth_time", sr0)
+    data_vars["slant_range_time"] = ("azimuth_time", slant_range_time)
+    data_vars["srgrCoefficients"] = (("azimuth_time", "degree"), srgrCoefficients)
+    data_vars["grsrCoefficients"] = (("azimuth_time", "degree"), grsrCoefficients)
 
     return xr.Dataset(data_vars=data_vars, coords=coords, attrs=attrs)
 
@@ -269,7 +270,7 @@ def open_gcp_dataset(
 
     footprint = get_footprint_linestring(ds.azimuth_time, ds.slant_range_time, ds)
     geospatial_attrs = make_geospatial_attributes(footprint)
-    ds.attrs.update(geospatial_attrs)  # type: ignore
+    ds.attrs.update(geospatial_attrs)
 
     return ds
 
@@ -351,35 +352,14 @@ def open_attitude_dataset(
     return ds
 
 
-def open_orbit_dataset(
-    annotation: esa_safe.PathOrFileType, attrs: Dict[str, Any] = {}
+def make_orbit(
+    azimuth_time: List[Any],
+    positions: List[List[Any]],
+    velocities: List[List[Any]],
+    attrs: Dict[str, Any] = {},
 ) -> xr.Dataset:
-    orbits = esa_safe.parse_tag_as_list(annotation, ".//orbit")
-
-    reference_system = orbits[0]["frame"]
-    variables = ["position", "velocity"]
-    data: Dict[str, List[Any]] = {var: [[], [], []] for var in variables}
-    azimuth_time: List[Any] = []
-    for orbit in orbits:
-        azimuth_time.append(orbit["time"])
-        data["position"][0].append(orbit["position"]["x"])
-        data["position"][1].append(orbit["position"]["y"])
-        data["position"][2].append(orbit["position"]["z"])
-        data["velocity"][0].append(orbit["velocity"]["x"])
-        data["velocity"][1].append(orbit["velocity"]["y"])
-        data["velocity"][2].append(orbit["velocity"]["z"])
-        if orbit["frame"] != reference_system:
-            warnings.warn(
-                "reference_system is not consistent in all the state vectors. "
-            )
-            reference_system = None
-
-    position = xr.Variable(data=data["position"], dims=("axis", "azimuth_time"))  # type: ignore
-    velocity = xr.Variable(data=data["velocity"], dims=("axis", "azimuth_time"))  # type: ignore
-
-    attrs = attrs.copy()
-    if reference_system is not None:
-        attrs.update({"reference_system": reference_system})
+    position = xr.Variable(data=positions, dims=("axis", "azimuth_time"))  # type: ignore
+    velocity = xr.Variable(data=velocities, dims=("axis", "azimuth_time"))  # type: ignore
 
     ds = xr.Dataset(
         data_vars={"position": position, "velocity": velocity},
@@ -395,6 +375,36 @@ def open_orbit_dataset(
     return ds
 
 
+def open_orbit_dataset(
+    annotation: esa_safe.PathOrFileType, attrs: Dict[str, Any] = {}
+) -> xr.Dataset:
+    orbits = esa_safe.parse_tag_as_list(annotation, ".//orbit")
+
+    attrs = attrs.copy()
+    reference_system = orbits[0]["frame"]
+    if reference_system is not None:
+        attrs.update({"reference_system": reference_system})
+
+    azimuth_times: List[Any] = []
+    positions: List[List[Any]] = [[], [], []]
+    velocities: List[List[Any]] = [[], [], []]
+    for orbit in orbits:
+        azimuth_times.append(orbit["time"])
+        positions[0].append(orbit["position"]["x"])
+        positions[1].append(orbit["position"]["y"])
+        positions[2].append(orbit["position"]["z"])
+        velocities[0].append(orbit["velocity"]["x"])
+        velocities[1].append(orbit["velocity"]["y"])
+        velocities[2].append(orbit["velocity"]["z"])
+        if orbit["frame"] != reference_system:
+            warnings.warn(
+                "reference_system is not consistent in all the state vectors. "
+            )
+            reference_system = None
+
+    return make_orbit(azimuth_times, positions, velocities, attrs)
+
+
 def open_dc_estimate_dataset(
     annotation: esa_safe.PathOrFileType, attrs: Dict[str, Any] = {}
 ) -> xr.Dataset:
@@ -511,7 +521,13 @@ def open_rasterio_dataarray(
                 raise FileNotFoundError(str(ex))
             raise
     else:
-        arr = xr.open_dataarray(fs.open(measurement), engine="rasterio", chunks=chunks)
+        # FIXME: rioxarray / rasterio do not support opening a file object any more, so
+        #   full fsspec support via `fs.open(measurement)` is now broken and we fall back
+        #   to hope that rasterio remote protocols works with fsspec urlpaths
+        maybe_rasterio_urlpath = fs.unstrip_protocol(measurement)
+        arr = xr.open_dataarray(
+            maybe_rasterio_urlpath, engine="rasterio", chunks=chunks
+        )
     return arr
 
 
@@ -653,22 +669,22 @@ def open_pol_dataset(
     arr = arr.swap_dims(swap_dims)
 
     if gcp:
-        attrs.update(gcp.attrs)  # type: ignore
+        attrs.update(gcp.attrs)
 
     arr.attrs.update(attrs)
-    arr.encoding.update(encoding)  # type: ignore
+    arr.encoding.update(encoding)
 
     return xr.Dataset(attrs=attrs, data_vars={"measurement": arr})
 
 
 def find_bursts_index(
     pol_dataset: DataArrayOrDataset,
-    azimuth_anx_time: float,
+    azimuth_anx_seconds: float,
     use_center: bool = False,
 ) -> int:
     lines_per_burst = pol_dataset.attrs["lines_per_burst"]
     anx_datetime = np.datetime64(pol_dataset.attrs["ascending_node_time"])
-    azimuth_anx_time = pd.Timedelta(azimuth_anx_time, unit="s")
+    azimuth_anx_time = pd.Timedelta(azimuth_anx_seconds, unit="s")
     if use_center:
         azimuth_anx_time_center = (
             pol_dataset.azimuth_time[lines_per_burst // 2 :: lines_per_burst]
@@ -756,7 +772,7 @@ def crop_burst_dataset(
     if gcp is not None:
         footprint = get_footprint_linestring(ds.azimuth_time, ds.slant_range_time, gcp)
         geospatial_attrs = make_geospatial_attributes(footprint)
-        ds.attrs.update(geospatial_attrs)  # type: ignore
+        ds.attrs.update(geospatial_attrs)
 
     if "burst_ids" in ds.attrs:
         ds.attrs["burst_id"] = ds.attrs["burst_ids"][burst_index]
